Usage
-----
:samp:`translate [-h] [-V] [{source}] {dest}`

py-translate is a CLI Tool for Google Translate written in Python!

positional arguments::

-source         Source language to convert from
-dest           Destination language to convert into


optional arguments::

-h, --help     show this help message and exit
-V, --version  show program's version number and exit
